=== modified file 'mysys/cached_directory.cc'
--- mysys/cached_directory.cc	2009-10-29 06:13:56 +0000
+++ mysys/cached_directory.cc	2009-11-02 23:01:41 +0000
@@ -46,11 +46,11 @@
 }
 
 
-CachedDirectory::CachedDirectory(const string& in_path, set<string>& exts) :
+CachedDirectory::CachedDirectory(const string& in_path, set<string>& allowed_exts) :
   error(0)
 {
   // TODO: Toss future exception
-  (void) open(in_path, exts, true);
+  (void) open(in_path, allowed_exts);
 }
 
 
@@ -64,15 +64,14 @@
   entries.clear();
 }
 
-
 bool CachedDirectory::open(const string &in_path)
 {
   set<string> empty;
 
-  return open(in_path, empty, false);
+  return open(in_path, empty);
 }
 
-bool CachedDirectory::open(const string &in_path, set<string> exts, bool honor_exts)
+bool CachedDirectory::open(const string &in_path, set<string> &allowed_exts)
 {
   DIR *dirp= opendir(in_path.c_str());
 
@@ -84,9 +83,6 @@
 
   path= in_path;
 
-  if (exts.size() == 0 && honor_exts)
-    return true;
-
   union {
     dirent entry;
 #ifdef __sun
@@ -107,16 +103,16 @@
   while ((retcode= readdir_r(dirp, &buffer.entry, &result)) == 0 &&
          result != NULL)
   {
-    if (exts.size())
+    if (! allowed_exts.empty())
     {
       char *ptr= rindex(result->d_name, '.');
 
       if (ptr)
       {
         set<string>::iterator it;
-        it= exts.find(ptr);
+        it= allowed_exts.find(ptr);
 
-        if (it != exts.end())
+        if (it != allowed_exts.end())
         {
           entries.push_back(new Entry(result->d_name));
         }

=== modified file 'mysys/cached_directory.h'
--- mysys/cached_directory.h	2009-10-30 15:58:06 +0000
+++ mysys/cached_directory.h	2009-11-02 23:01:41 +0000
@@ -45,8 +45,6 @@
  */
 class CachedDirectory
 {
-  std::string path;
-
 public:
   class Entry
   {
@@ -57,14 +55,8 @@
     {}
   };
   typedef std::vector<Entry *> Entries;
-private:
-  int error; ///< Error code stored from various syscalls
-  Entries entries; ///< Entries in the directory
-
-public:
   /**
-   * Emptry Constructor.
-   *
+   * Empty Constructor.
    */
   CachedDirectory();
       
@@ -72,14 +64,21 @@
    * Constructor taking full directory path as sole parameter.
    *
    * @param[in] Path to the directory to open
-   * @param[in] File extensions to mask against.
-   */
- CachedDirectory(const std::string& in_path); 
- CachedDirectory(const std::string& in_path, std::set<std::string>& exts);
-
- /**
-  * Destructor.  Cleans up any resources we've taken 
-  */
+   * @param[in] File extensions to allow
+   */
+  CachedDirectory(const std::string& in_path); 
+
+  /**
+   * Constructor taking full directory path as sole parameter.
+   *
+   * @param[in] Path to the directory to open
+   * @param[in] File extensions to allow
+   */
+  CachedDirectory(const std::string& in_path, std::set<std::string>& allowed_exts);
+
+  /**
+   * Destructor.  Cleans up any resources we've taken 
+   */
   ~CachedDirectory();
 
   /**
@@ -117,17 +116,31 @@
   {
     return entries;
   }
+private:
+  std::string path; ///< Path to the directory
+  int error; ///< Error code stored from various syscalls
+  Entries entries; ///< Entries in the directory
 
   /**
    * Encapsulate the logic to open the directory.
-   * @param[in] dirPath The path to the directory to open and read.
-   * @param[in] File extensions to mask against.
+   * @param[in] The path to the directory to open and read
+   *
    * @retval true Success
    * @retval false Failure
    */
-  bool open(const std::string &dirPath);
-  bool open(const std::string &in_path, std::set<std::string> exts, bool honor_exts= true);
+  bool open(const std::string &in_path);
 
+  /**
+   * Encapsulate the logic to open the directory with a set of allowed
+   * file extensions to filter for.
+   *
+   * @param[in] The path to the directory to open and read
+   * @param[in] File extensions to allow
+   *
+   * @retval true Success
+   * @retval false Failure
+   */
+  bool open(const std::string &in_path, std::set<std::string> &allowable_exts);
 };
 
 #endif /* MYSYS_CACHED_DIRECTORY_H */

